"""Cricguru

This package contains functions for retrieving data from the Statsguru data query on ESPN Cricinfo. The main
classes cover teams and players data. The results are returned as a Pandas dataframe in order to facilitate
data analysis on cricket data.

"""
